@@ -36,8 +36,7 @@ class action_plugin_fckg_cache extends DokuWiki_Action_Plugin {
 
     function fckg_cache_bypass(&$event, $param)
     {
-
-     if(!$this->pos) {
+      if(!$this->pos && file_exists($event->data->file)) {     
          $data=file_get_contents($event->data->file);
          $this->pos = strpos($data,"<indent");
      }
