@@ -25,10 +25,10 @@
 
 FCKCommands.RegisterCommand( 'Format_Table',
    new FCKDialogCommand( "Format Table", "Format Table",  
-   FCKConfig.PluginsPath + 'tableformat/replace.html', 600, 600 ) ) ;
+   FCKConfig.PluginsPath + 'tableformat/table.html', 600, 600 ) ) ;
 
 // Create the "Replace" toolbar button.
 var oReplaceItem		= new FCKToolbarButton( 'Format_Table', 'Format Table' ) ;
-oReplaceItem.IconPath	= FCKConfig.PluginsPath + 'tableformat/replace.gif' ;
+oReplaceItem.IconPath	= FCKConfig.PluginsPath + 'tableformat/table.gif' ;
 
 FCKToolbarItems.RegisterItem( 'Format_Table', oReplaceItem ) ;	// 'Format_Table' is the name used in the Toolbar config.
